@@ -60,7 +60,7 @@ extern std::unique_ptr<Options> gOptions;
 void SourceData::reset()
 {
     mFromClipBoard = false;
-    mEncoding = u8"UTF-8";
+    mEncoding = QByteArray();
     m_fileAccess = FileAccess();
     m_normalData.reset();
     m_lmppData.reset();
@@ -323,7 +323,7 @@ std::optional<const QByteArray> SourceData::detectEncoding(const QString& fileNa
     return {};
 }
 
-void SourceData::readAndPreprocess(const char* encoding, bool bAutoDetect)
+void SourceData::readAndPreprocess(const QByteArray& encoding, bool bAutoDetect)
 {
     QTemporaryFile fileIn1, fileOut1;
     QString fileNameIn1;
@@ -331,14 +331,16 @@ void SourceData::readAndPreprocess(const char* encoding, bool bAutoDetect)
     QString fileNameIn2;
     QString fileNameOut2;
 
-    mEncoding = encoding;
-
     // Detect the input for the preprocessing operations
     if(!mFromClipBoard)
     {
         //Routine result of directory compare finding a file that isn't in all locations.
         if(!m_fileAccess.isValid()) return;
 
+        mEncoding = encoding;
+        if(mEncoding.isEmpty())
+            mEncoding = u8"UTF-8";
+
         assert(!m_fileAccess.exists() || !m_fileAccess.isDir());
         if(!m_fileAccess.isNormal())
         {
@@ -360,10 +362,6 @@ void SourceData::readAndPreprocess(const char* encoding, bool bAutoDetect)
 
             fileNameIn1 = m_tempInputFileName;
         }
-        if(bAutoDetect)
-        {
-            mEncoding = detectEncoding(fileNameIn1).value_or(encoding);
-        }
     }
     else // The input was set via setData(), probably from clipboard.
     {
@@ -375,6 +373,12 @@ void SourceData::readAndPreprocess(const char* encoding, bool bAutoDetect)
         fileNameIn1 = m_tempInputFileName;
         mEncoding = "UTF-8";
     }
+
+    if(bAutoDetect)
+    {
+        mEncoding = detectEncoding(fileNameIn1).value_or(encoding);
+    }
+
     QByteArray pEncoding1 = getEncoding();
     QByteArray pEncoding2 = getEncoding();
     const QString overSizedFile = i18nc("Error message. %1 = filepath", "File %1 too large to process. Skipping.", fileNameIn1);
@@ -581,8 +585,6 @@ bool SourceData::FileData::preprocess(const QByteArray& encoding, bool removeCom
     m_eLineEndStyle = eLineEndStyleUndefined;
 
     QByteArray pCodec = detectEncoding(m_pBuf.get(), mDataSize, skipBytes).value_or(encoding);
-    if(pCodec != encoding)
-        skipBytes = 0;
 
     if(mDataSize - skipBytes > limits<qint32>::max())
     {
@@ -597,7 +599,6 @@ bool SourceData::FileData::preprocess(const QByteArray& encoding, bool removeCom
 
         mHasBOM = skipBytes != 0;
         ds.setEncoding(encoding);
-        ds.setGenerateByteOrderMark(skipBytes != 0);
 
         m_bIncompleteConversion = false;
         m_unicodeBuf->clear();
@@ -818,9 +819,9 @@ std::optional<const QByteArray> SourceData::detectEncoding(const char* buf, qint
         We don't need the whole file here just the header.
     */
     if(size <= 5000)
-        s = QByteArray(buf, (QtSizeType)size);
+        s = QByteArray::fromRawData(buf, (QtSizeType)size);
     else
-        s = QByteArray(buf, 5000);
+        s = QByteArray::fromRawData(buf, 5000);
 
     QtSizeType xmlHeaderPos = s.indexOf("<?xml");
     if(xmlHeaderPos >= 0)
@@ -828,7 +829,7 @@ std::optional<const QByteArray> SourceData::detectEncoding(const char* buf, qint
         QtSizeType xmlHeaderEnd = s.indexOf("?>", xmlHeaderPos);
         if(xmlHeaderEnd >= 0)
         {
-            std::optional<const char*> encoding = getEncodingFromTag(s.mid(xmlHeaderPos, xmlHeaderEnd - xmlHeaderPos), "encoding=");
+            std::optional<QByteArray> encoding = getEncodingFromTag(s.mid(xmlHeaderPos, xmlHeaderEnd - xmlHeaderPos), "encoding=");
             if(encoding.has_value())
                 return encoding;
         }
@@ -841,7 +842,7 @@ std::optional<const QByteArray> SourceData::detectEncoding(const char* buf, qint
             QtSizeType metaHeaderEnd = s.indexOf(">", metaHeaderPos);
             if(metaHeaderEnd >= 0)
             {
-                std::optional<const char*> encoding = getEncodingFromTag(s.mid(metaHeaderPos, metaHeaderEnd - metaHeaderPos), "charset=");
+                std::optional<QByteArray> encoding = getEncodingFromTag(s.mid(metaHeaderPos, metaHeaderEnd - metaHeaderPos), "charset=");
                 if(encoding.has_value())
                     return encoding;
 
