@@ -87,7 +87,8 @@ class DataReadTest: public QObject
         QVERIFY(!simData.isFromBuffer());
         QVERIFY(!simData.isEmpty());
         QVERIFY(simData.hasData());
-        QVERIFY(simData.getEncoding() != nullptr);
+        QVERIFY(!simData.hasBOM());
+        QVERIFY(!simData.getEncoding().isEmpty());
         QCOMPARE(simData.getSizeLines(), 5);
         QCOMPARE(simData.getSizeBytes(), file.size());
     }
@@ -228,7 +229,7 @@ class DataReadTest: public QObject
         QVERIFY(!simData.isFromBuffer());
         QVERIFY(!simData.isEmpty());
         QVERIFY(simData.hasData());
-        QVERIFY(simData.getEncoding() != nullptr);
+        QVERIFY(!simData.getEncoding().isEmpty());
 
         QVERIFY(simData.hasEOLTermiantion());
         QCOMPARE(simData.getSizeLines(), 3);
