@@ -811,10 +811,10 @@ bool FileAccess::readFile(void* pDestBuffer, qint64 maxLength)
     else
     {
         success = mJobHandler->get(pDestBuffer, maxLength);
+        close();
     }
 
-    close();
-    assert(!realFile->isOpen() && !tmpFile->isOpen());
+    assert((realFile == nullptr || !realFile->isOpen()) && !tmpFile->isOpen());
     return success;
 }
 
@@ -854,6 +854,7 @@ bool FileAccess::writeFile(const void* pSrcBuffer, qint64 length)
             }
 
             realFile->close();
+            assert((realFile == nullptr || !realFile->isOpen()) && !tmpFile->isOpen());
             return true;
         }
     }
@@ -862,12 +863,11 @@ bool FileAccess::writeFile(const void* pSrcBuffer, qint64 length)
         bool success = mJobHandler->put(pSrcBuffer, length, true /*overwrite*/);
         close();
 
-        assert(!realFile->isOpen() && !tmpFile->isOpen());
-
+        assert((realFile == nullptr || !realFile->isOpen()) && !tmpFile->isOpen());
         return success;
     }
-    close();
-    assert(!realFile->isOpen() && !tmpFile->isOpen());
+
+    assert((realFile == nullptr || !realFile->isOpen()) && !tmpFile->isOpen());
     return false;
 }
 
@@ -929,12 +929,14 @@ bool FileAccess::open(const QFile::OpenMode flags)
     {
         bool r = realFile->open(flags);
 
-        setStatusText(i18n("Opening %1 failed. %2", absoluteFilePath(), realFile->errorString()));
+        if(!r)
+            setStatusText(i18n("Opening %1 failed. %2", absoluteFilePath(), realFile->errorString()));
         return r;
     }
 
     bool r = tmpFile->open();
-    setStatusText(i18n("Opening %1 failed. %2", tmpFile->fileName(), tmpFile->errorString()));
+    if(!r)
+        setStatusText(i18n("Opening %1 failed. %2", tmpFile->fileName(), tmpFile->errorString()));
     return r;
 }
 
